@@ -59,10 +59,10 @@ $map {$_} = "?" for
     "pxm\100nubz.org",
     "raf\100tradingpost.com.au",
     "smoketst\100hp46t243.cup.hp.com",
-		"oracle\100pcr8.pcr.com". # Probably Ed Eddington ed@pcr.com
-		"root\100chronos.fi.muni.cz", # no clue - jrv 20090803
-		"gomar\100md.media-web.de", # no clue - jrv 20090803
-		"data-drift\100so.uio.no", # no data. originally private message from 199701282014.VAA12645@selters.uio.no
+        "oracle\100pcr8.pcr.com". # Probably Ed Eddington ed@pcr.com
+        "root\100chronos.fi.muni.cz", # no clue - jrv 20090803
+        "gomar\100md.media-web.de", # no clue - jrv 20090803
+        "data-drift\100so.uio.no", # no data. originally private message from 199701282014.VAA12645@selters.uio.no
 
 ;
 
@@ -77,7 +77,7 @@ $map {$_} = '!' for
      "nik\100tiuk.ti.com",
      "nick.ing-simmons\100elixent.com",
      "nick\100ni-s.u-net.com",
-	 "nick.ing-simmons\100tiuk.ti.com",
+     "nick.ing-simmons\100tiuk.ti.com",
 
      # Iain Truskett has passed away (2003-12-29).
      "perl\100dellah.anu.edu.au",
@@ -97,19 +97,19 @@ $map {$_} = '!' for
 
      # perl internal addresses
      "perl5-porters\100africa.nicoh.com",
-	 "perlbug\100perl.org",,
+     "perlbug\100perl.org",,
      "perl5-porters.nicoh.com",
-	 "perlbug-followup\100perl.org",
-	 "perlbug-comment\100perl.org",
-	 "bug-module-corelist\100rt.cpan.org",
-	 "bug-storable\100rt.cpan.org",
-	 "bugs-perl5\100bugs6.perl.org",
-	 "unknown",
-	 "unknown\100unknown",
-	 "unknown\100longtimeago",
-	 "unknown\100perl.org",
-	"",
-	"(none)",
+     "perlbug-followup\100perl.org",
+     "perlbug-comment\100perl.org",
+     "bug-module-corelist\100rt.cpan.org",
+     "bug-storable\100rt.cpan.org",
+     "bugs-perl5\100bugs6.perl.org",
+     "unknown",
+     "unknown\100unknown",
+     "unknown\100longtimeago",
+     "unknown\100perl.org",
+    "",
+    "(none)",
 ;
 
 
@@ -270,7 +270,7 @@ craigb                                  craig.berry\100psinetcs.com
 +                                       craig.berry\100signaltreesolutions.com
 +                                       craigberry\100mac.com
 +                                       craig.a.berry\100gmail.com
-+										craig a. berry)
++                                        craig a. berry)
 davem                                   davem\100fdgroup.com
 +                                       davem\100iabyn.nospamdeletethisbit.com
 +                                       davem\100iabyn.com
@@ -294,7 +294,7 @@ gbarr                                   gbarr\100pobox.com
 +                                       bodg\100tiuk.ti.com
 +                                       gbarr\100ti.com
 +                                       graham.barr\100tiuk.ti.com
-+										gbarr\100monty.mutatus.co.uk
++                                        gbarr\100monty.mutatus.co.uk
 gisle                                   gisle\100activestate.com
 +                                       gisle\100aas.no
 +                                       aas\100aas.no
@@ -319,23 +319,24 @@ jesse                                   jesse\100bestpractical.com
 merijn                                  h.m.brand\100xs4all.nl
 +                                       h.m.brand\100hccnet.nl
 +                                       merijn\100l1.procura.nl
-+										merijn\100a5.(none)
++                                        merijn\100a5.(none)
 mhx                                     mhx-perl\100gmx.net
-+										mhx\100r2d2.(none)
++                                        mhx\100r2d2.(none)
 nicholas                                nick\100unfortu.net
 +                                       nick\100ccl4.org
 +                                       nick\100talking.bollo.cx
 +                                       nick\100plum.flirble.org
 +                                       nick\100babyhippo.co.uk
 +                                       nick\100bagpuss.unfortu.net
-+										nick\100babyhippo.com
-+										Nicholas Clark (sans From field in mail header)
++                                        nick\100babyhippo.com
++                                        Nicholas Clark (sans From field in mail header)
 pudge                                   pudge\100pobox.com
 rgs                                     rgarciasuarez\100free.fr
 +                                       rgarciasuarez\100mandrakesoft.com
 +                                       rgarciasuarez\100mandriva.com
 +                                       rgarciasuarez\100gmail.com
 +                                       raphel.garcia-suarez\100hexaflux.com
++                                       rgs@consttype.org
 sky                                     sky\100nanisky.com
 +                                       artur\100contiller.se
 +                                       arthur\100contiller.se
@@ -343,7 +344,7 @@ steveh                                  stevehay\100planit.com
 +                                       steve.hay\100uk.radan.com
 stevep                                  steve\100fisharerojo.org
 +                                       steve.peters\100gmail.com
-+										root\100dixie.cscaper.com
++                                        root\100dixie.cscaper.com
 timb                                    Tim.Bunce\100pobox.com
 +                                       tim.bunce\100ig.co.uk
 
@@ -361,27 +362,27 @@ timb                                    Tim.Bunce\100pobox.com
 +                                       l2ot9pa02\100sneakemail.com
 +                                       wyp3rlx02\100sneakemail.com
 +                                       0mgwtfbbq\100sneakemail.com
-+										xyey9001\100sneakemail.com
++                                        xyey9001\100sneakemail.com
 a.r.ferreira\100gmail.com               aferreira\100shopzilla.com
 abe\100ztreet.demon.nl                  abeltje\100cpan.org
 abela\100hsc.fr                         abela\100geneanet.org
 abigail\100abigail.be                   abigail\100foad.org
 +                                       abigail\100abigail.nl
 +                                       abigail\100fnx.com
-aburt\100isis.cs.du.edu					isis!aburt
+aburt\100isis.cs.du.edu                    isis!aburt
 ach\100mpe.mpg.de                       ach\100rosat.mpe-garching.mpg.de
-adavies\100ptc.com						alex.davies\100talktalk.net
+adavies\100ptc.com                        alex.davies\100talktalk.net
 ajohnson\100nvidia.com                  ajohnson\100wischip.com
-+										anders\100broadcom.com
++                                        anders\100broadcom.com
 alexm\100netli.com                      alexm\100w-m.ru
 alex-p5p\100earth.li                    alex\100rcon.rog
 alexmv\100mit.edu                       alex\100chmrr.net
 alian\100cpan.org                       alian\100alianwebserver.com
 allen\100grumman.com                    allen\100gateway.grumman.com
 allen\100huarp.harvard.edu              nort\100bottesini.harvard.edu
-+										nort\100qnx.com
++                                        nort\100qnx.com
 allens\100cpan.org                      easmith\100beatrice.rutgers.edu
-+										root\100dogberry.rutgers.edu
++                                        root\100dogberry.rutgers.edu
 andreas.koenig\100anima.de              andreas.koenig.gmwojprw\100franz.ak.mind.de
 +                                       andreas.koenig.7os6vvqr\100franz.ak.mind.de
 +                                       a.koenig\100mind.de
@@ -389,35 +390,37 @@ andreas.koenig\100anima.de              andreas.koenig.gmwojprw\100franz.ak.mind
 +                                       andk\100cpan.org
 +                                       koenig\100anna.mind.de
 +                                       k\100anna.mind.de
-+										root\100ak-71.mind.de
-+										root\100ak-75.mind.de
-+										k\100sissy.in-berlin.de
-+										a.koenig\100kulturbox.de
-+										k\100sissy.in-berlin.de
-+										root\100dubravka.in-berlin.de
++                                        root\100ak-71.mind.de
++                                        root\100ak-75.mind.de
++                                        k\100sissy.in-berlin.de
++                                        a.koenig\100kulturbox.de
++                                        k\100sissy.in-berlin.de
++                                        root\100dubravka.in-berlin.de
 anno4000\100lublin.zrz.tu-berlin.de     anno4000\100mailbox.tu-berlin.de
 +                                       siegel\100zrz.tu-berlin.de
-arnold\100gnu.ai.mit.edu					arnold\100emoryu2.arpa
-+										gatech!skeeve!arnold
-arussell\100cs.uml.edu					adam\100adam-pc.(none)
+arnold\100gnu.ai.mit.edu                    arnold\100emoryu2.arpa
++                                        gatech!skeeve!arnold
+arussell\100cs.uml.edu                    adam\100adam-pc.(none)
 ash\100cpan.org                         ash_cpan\100firemirror.com
 avarab\100gmail.com                     avar\100cpan.org
 
 bailey\100newman.upenn.edu              bailey\100hmivax.humgen.upenn.edu
 +                                       bailey\100genetics.upenn.edu
-+										bailey.charles\100gmail.com
++                                        bailey.charles\100gmail.com
 bah\100ecnvantage.com                   bholzman\100longitude.com
-barries\100slaysys.com					root\100jester.slaysys.com
-bkedryna\100home.com						bart\100cg681574-a.adubn1.nj.home.com
+barries\100slaysys.com                    root\100jester.slaysys.com
+bkedryna\100home.com                        bart\100cg681574-a.adubn1.nj.home.com
 bcarter\100gumdrop.flyinganvil.org      q.eibcartereio.=~m-b.{6}-cgimosx\100gumdrop.flyinganvil.org
 ben_tilly\100operamail.com              btilly\100gmail.com
-+										ben_tilly\100hotmail.com
-ben\100morrow.me.uk						mauzo\100csv.warwick.ac.uk
-+										mauzo\100.(none)
-BQW10602\100nifty.com					sadahiro\100cpan.org
++                                        ben_tilly\100hotmail.com
+ben\100morrow.me.uk                        mauzo\100csv.warwick.ac.uk
++                                        mauzo\100.(none)
+bepi\100perl.it                        enrico.sorcinelli\100gmail.com
+brian.d.foy\100gmail.com                bdfoy\100cpan.org
+BQW10602\100nifty.com                    sadahiro\100cpan.org
 
 chromatic\100wgz.org                    chromatic\100rmci.net
-clintp\100geeksalad.org					cpierce1\100ford.com
+clintp\100geeksalad.org                    cpierce1\100ford.com
 clkao\100clkao.org                      clkao\100bestpractical.com
 corion\100corion.net                    corion\100cpan.org
 cp\100onsitetech.com                    publiustemp-p5p\100yahoo.com
@@ -428,91 +431,91 @@ cpan\100audreyt.org                     autrijus\100egb.elixus.org
 +                                       autrijus\100ossf.iis.sinica.edu.tw
 +                                       autrijus\100autrijus.org
 +                                       audreyt\100audreyt.org
-cpan\100ton.iguana.be					me-01\100ton.iguana.be
-crt\100kiski.net						perl\100ctweten.amsite.com
+cpan\100ton.iguana.be                    me-01\100ton.iguana.be
+crt\100kiski.net                        perl\100ctweten.amsite.com
 
-damian\100conway.org					damian\100cs.monash.edu.au
+damian\100conway.org                    damian\100cs.monash.edu.au
 dagolden\100cpan.org                    xdaveg\100gmail.com
 dan\100sidhe.org                        sugalsd\100lbcc.cc.or.us
 +                                       sugalskd\100osshe.edu
-daniel\100bitpusher.com					daniel\100biz.bitpusher.com
+daniel\100bitpusher.com                    daniel\100biz.bitpusher.com
 david.dyck\100fluke.com                 dcd\100tc.fluke.com
-david\100kineticode.com					david\100wheeler.com
-+										david\100wheeler.net
-dev-perl\100pimb.org					knew-p5p\100pimb.org
-djberg86\100attbi.com					djberg96\100attbi.com
+david\100kineticode.com                    david\100wheeler.com
++                                        david\100wheeler.net
+dev-perl\100pimb.org                    knew-p5p\100pimb.org
+djberg86\100attbi.com                    djberg96\100attbi.com
 domo\100computer.org                    shouldbedomo\100mac.com
 +                                       domo\100slipper.ip.lu
-+										domo\100tcp.ip.lu
++                                        domo\100tcp.ip.lu
 dougm\100covalent.net                   dougm\100opengroup.org
 +                                       dougm\100osf.org
-dougw\100cpan.org						doug_wilson\100intuit.com
-dwegscheid\100qtm.net						wegscd\100whirlpool.com
-edwardp\100excitehome.net					epeschko\100den-mdev1
-+										epeschko\100elmer.tci.com
+dougw\100cpan.org                        doug_wilson\100intuit.com
+dwegscheid\100qtm.net                        wegscd\100whirlpool.com
+edwardp\100excitehome.net                    epeschko\100den-mdev1
++                                        epeschko\100elmer.tci.com
 egf7\100columbia.edu                    efifer\100sanwaint.com
-eggert\100twinsun.com					eggert\100sea.sm.unisys.com
+eggert\100twinsun.com                    eggert\100sea.sm.unisys.com
 epeschko\100den-mdev1                   esp5\100pge.com
 
 fugazi\100zyx.net                       larrysh\100cpan.org
-+										lshatzer\100islanddata.com
++                                        lshatzer\100islanddata.com
 
-gbacon\100itsc.uah.edu						gbacon\100adtrn-srv4.adtran.com
-gerberb\100zenez.com					root\100devsys0.zenez.com
-gfuji\100cpan.org						g.psy.va\100gmail.com
+gbacon\100itsc.uah.edu                        gbacon\100adtrn-srv4.adtran.com
+gerberb\100zenez.com                    root\100devsys0.zenez.com
+gfuji\100cpan.org                        g.psy.va\100gmail.com
 gibreel\100pobox.com                    stephen.zander\100interlock.mckesson.com
 +                                       srz\100loopback
 gnat\100frii.com                        gnat\100prometheus.frii.com
 gp\100familiehaase.de                   gerrit\100familiehaase.de
 grazz\100pobox.com                      grazz\100nyc.rr.com
-gward\100ase.com						greg\100bic.mni.mcgill.ca
+gward\100ase.com                        greg\100bic.mni.mcgill.ca
 hansmu\100xs4all.nl                     hansm\100icgroup.nl
 +                                       hansm\100icgned.nl
 +                                       hans\100icgned.nl
 +                                       hans\100icgroup.nl
 +                                       hansm\100euronet.nl
-+										hansm\100euro.net
++                                        hansm\100euro.net
 hio\100ymir.co.jp                       hio\100hio.jp
-hops\100sco.com							hops\100scoot.pdev.sco.com
+hops\100sco.com                            hops\100scoot.pdev.sco.com
 
-ingo_weinhold\100gmx.de					bonefish\100cs.tu-berlin.de
+ingo_weinhold\100gmx.de                    bonefish\100cs.tu-berlin.de
 
-james\100mastros.biz						theorb\100desert-island.me.uk
-jand\100activestate.com					jan.dubois\100ibm.net
+james\100mastros.biz                        theorb\100desert-island.me.uk
+jand\100activestate.com                    jan.dubois\100ibm.net
 japhy\100pobox.com                      japhy\100pobox.org
 +                                       japhy\100perlmonk.org
 +                                       japhy\100cpan.org
-+										jeffp\100crusoe.net
++                                        jeffp\100crusoe.net
 jari.aalto\100poboxes.com               jari.aalto\100cante.net
-jarausch\100numa1.igpm.rwth-aachen.de	helmutjarausch\100unknown
-jasons\100cs.unm.edu						jasons\100sandy-home.arc.unm.edu
-jbuehler\100hekimian.com					jhpb\100hekimian.com
+jarausch\100numa1.igpm.rwth-aachen.de    helmutjarausch\100unknown
+jasons\100cs.unm.edu                        jasons\100sandy-home.arc.unm.edu
+jbuehler\100hekimian.com                    jhpb\100hekimian.com
 jcromie\100100divsol.com                   jcromie\100cpan.org
 +                                       jim.cromie\100gmail.com
-jidanni\100jidanni.org					jidanni\100hoffa.dreamhost.com
+jidanni\100jidanni.org                    jidanni\100hoffa.dreamhost.com
 jdhedden\100cpan.org                    jerry\100hedden.us
 +                                       jdhedden\1001979.usna.com
 +                                       jdhedden\100gmail.com
 +                                       jdhedden\100yahoo.com
-+										jhedden\100pn100-02-2-356p.corp.bloomberg.com
-jeremy\100zawodny.com					jzawodn\100wcnet.org
-jesse\100sig.bsh.com					jesse\100ginger
++                                        jhedden\100pn100-02-2-356p.corp.bloomberg.com
+jeremy\100zawodny.com                    jzawodn\100wcnet.org
+jesse\100sig.bsh.com                    jesse\100ginger
 jfriedl\100yahoo.com                    jfriedl\100yahoo-inc.com
-jfs\100fluent.com						jfs\100jfs.fluent.com
-jhannah\100omnihotels.com					jay\100jays.net
+jfs\100fluent.com                        jfs\100jfs.fluent.com
+jhannah\100omnihotels.com                    jay\100jays.net
 jjore\100cpan.org                       twists\100gmail.com
 jns\100integration-house.com            jns\100gellyfish.com
 +                                       gellyfish\100gellyfish.com
-john\100atlantech.com					john\100titanic.atlantech.com
-john\100johnwright.org					john.wright\100hp.com
-joseph\100cscaper.com					joseph\1005sigma.com
-joshua\100rodd.us							jrodd\100pbs.org
-jtobey\100john-edwin-tobey.org				jtobey\100user1.channel1.com
+john\100atlantech.com                    john\100titanic.atlantech.com
+john\100johnwright.org                    john.wright\100hp.com
+joseph\100cscaper.com                    joseph\1005sigma.com
+joshua\100rodd.us                            jrodd\100pbs.org
+jtobey\100john-edwin-tobey.org                jtobey\100user1.channel1.com
 jpeacock\100rowman.com                  john.peacock\100havurah-software.org
 +                                       jpeacock\100havurah-software.org
-+										jpeacock\100dsl092-147-156.wdc1.dsl.speakeasy.net
-jql\100accessone.com					jql\100jql.accessone.com
-jsm28\100hermes.cam.ac.uk					jsm28\100cam.ac.uk
++                                        jpeacock\100dsl092-147-156.wdc1.dsl.speakeasy.net
+jql\100accessone.com                    jql\100jql.accessone.com
+jsm28\100hermes.cam.ac.uk                    jsm28\100cam.ac.uk
 
 kane\100dwim.org                        kane\100xs4all.net
 +                                       kane\100cpan.org
@@ -520,65 +523,66 @@ kane\100dwim.org                        kane\100xs4all.net
 +                                       jos\100dwim.org
 +                                       jib\100ripe.net
 ken\100mathforum.org                    kenahoo\100gmail.com
++                                        ken.williams\100thomsonreuters.com
 kroepke\100dolphin-services.de          kay\100dolphin-services.de
 kstar\100wolfetech.com                  kstar\100cpan.org
 +                                       kurt_starsinic\100ml.com
-+										kstar\100www.chapin.edu
-+										kstar\100chapin.edu
++                                        kstar\100www.chapin.edu
++                                        kstar\100chapin.edu
 larry\100wall.org                       lwall\100jpl-devvax.jpl.nasa.gov
 +                                       lwall\100netlabs.com
 +                                       larry\100netlabs.com
 +                                       lwall\100sems.com
 +                                       lwall\100scalpel.netlabs.com
-laszlo.molnar\100eth.ericsson.se			molnarl\100cdata.tvnet.hu
-+										ml1050\100freemail.hu
+laszlo.molnar\100eth.ericsson.se            molnarl\100cdata.tvnet.hu
++                                        ml1050\100freemail.hu
 lewart\100uiuc.edu                      lewart\100vadds.cvm.uiuc.edu    
 +                                       d-lewart\100uiuc.edu
-lstein\100cshl.org						lstein\100formaggio.cshl.org
-+										lstein\100genome.wi.mit.edu
-lupe\100lupe-christoph.de					lupe\100alanya.m.isar.de
-lutherh\100stratcom.com					lutherh\100infinet.com
-mab\100wdl.loral.com						markb\100rdcf.sm.unisys.com
+lstein\100cshl.org                        lstein\100formaggio.cshl.org
++                                        lstein\100genome.wi.mit.edu
+lupe\100lupe-christoph.de                    lupe\100alanya.m.isar.de
+lutherh\100stratcom.com                    lutherh\100infinet.com
+mab\100wdl.loral.com                        markb\100rdcf.sm.unisys.com
 marcel\100codewerk.com                  gr\100univie.ac.at
-mark.p.lutz\100boeing.com					tecmpl1\100triton.ca.boeing.com
-marnix\100gmail.com						pttesac!marnix!vanam
+mark.p.lutz\100boeing.com                    tecmpl1\100triton.ca.boeing.com
+marnix\100gmail.com                        pttesac!marnix!vanam
 mats\100sm6sxl.net                      mats\100sm5sxl.net
 mbarbon\100dsi.unive.it                 mattia.barbon\100libero.it
 mcmahon\100ibiblio.org                  mcmahon\100metalab.unc.edu
-me\100davidglasser.net					glasser\100tang-eleven-seventy-nine.mit.edu
-merijnb\100iloquent.nl					merijnb\100ms.com
-+										merijnb\100iloquent.com
-merlyn\100stonehenge.com				merlyn\100gadget.cscaper.com
+me\100davidglasser.net                    glasser\100tang-eleven-seventy-nine.mit.edu
+merijnb\100iloquent.nl                    merijnb\100ms.com
++                                        merijnb\100iloquent.com
+merlyn\100stonehenge.com                merlyn\100gadget.cscaper.com
 mgjv\100comdyn.com.au                   mgjv\100tradingpost.com.au
-mlh\100swl.msd.ray.com						webtools\100uewrhp03.msd.ray.com
+mlh\100swl.msd.ray.com                        webtools\100uewrhp03.msd.ray.com
 michael.schroeder\100informatik.uni-erlangen.de mls\100suse.de
 mike\100stok.co.uk                      mike\100exegenix.com
 mjtg\100cam.ac.uk                       mjtg\100cus.cam.ac.uk
-mikedlr\100tardis.ed.ac.uk				mikedlr\100it.com.pl
+mikedlr\100tardis.ed.ac.uk                mikedlr\100it.com.pl
 moritz\100casella.verplant.org          moritz\100faui2k3.org
-+										moritz lenz
++                                        moritz lenz
 
-neale\100VMA.TABNSW.COM.AU				neale\100pucc.princeton.edu
-neeracher\100mac.com					neeri\100iis.ee.ethz.ch
-neil\100bowers.com						neilb\100cre.canon.co.uk
+neale\100VMA.TABNSW.COM.AU                neale\100pucc.princeton.edu
+neeracher\100mac.com                    neeri\100iis.ee.ethz.ch
+neil\100bowers.com                        neilb\100cre.canon.co.uk
 
 nospam-abuse\100bloodgate.com           tels\100bloodgate.com
 +                                       perl_dummy\100bloodgate.com
 
-ian.phillipps\100iname.com				ian_phillipps\100yahoo.co.uk
-+										ian\100dial.pipex.com
+ian.phillipps\100iname.com                ian_phillipps\100yahoo.co.uk
++                                        ian\100dial.pipex.com
 ignasi.roca\100fujitsu-siemens.com      ignasi.roca\100fujitsu.siemens.es
-ilmari\100ilmari.org					ilmari\100vesla.ilmari.org
-illpide\100telecel.pt						arbor\100al37al08.telecel.pt
+ilmari\100ilmari.org                    ilmari\100vesla.ilmari.org
+illpide\100telecel.pt                        arbor\100al37al08.telecel.pt
 # see http://www.nntp.perl.org/group/perl.perl5.porters/2001/01/msg28925.html
 #
 ilya\100math.berkeley.edu               ilya\100math.ohio-state.edu
 +                                       nospam-abuse\100ilyaz.org
-+										[9]ilya\100math.ohio-state.edu
-ilya\100martynov.org					ilya\100juil.nonet
++                                        [9]ilya\100math.ohio-state.edu
+ilya\100martynov.org                    ilya\100juil.nonet
 
 okamoto\100corp.hp.com                  okamoto\100hpcc123.corp.hp.com
-orwant\100oreilly.com					orwant\100media.mit.edu
+orwant\100oreilly.com                    orwant\100media.mit.edu
 
 p5-authors\100crystalflame.net          perl\100crystalflame.net
 +                                       rs\100crystalflame.net
@@ -586,62 +590,62 @@ p5-authors\100crystalflame.net          perl\100crystalflame.net
 +                                       coral\100moonlight.crystalflame.net
 +                                       rs\100oregonnet.com
 paul.green\100stratus.com               paul_greenvos\100vos.stratus.com
-+										pgreen\100seussnt.stratus.com
++                                        pgreen\100seussnt.stratus.com
 paul.marquess\100btinternet.com         paul_marquess\100yahoo.co.uk
 +                                       paul.marquess\100ntlworld.com
 +                                       paul.marquess\100openwave.com
 +                                       pmarquess\100bfsec.bt.co.uk
 +                                       pmqs\100cpan.org
-Pavel.Zakouril\100mff.cuni.cz				root\100egg.karlov.mff.cuni.cz
+Pavel.Zakouril\100mff.cuni.cz                root\100egg.karlov.mff.cuni.cz
 pcg\100goof.com                         schmorp\100schmorp.de
 perl\100cadop.com                       cdp\100hpescdp.fc.hp.com
-perl\100greerga.m-l.org					greerga\100m-l.org
+perl\100greerga.m-l.org                    greerga\100m-l.org
 perl\100profvince.com                   vince\100profvince.com
 perl-rt\100wizbit.be                    p5p\100perl.wizbit.be
 # Maybe we should special case this to get real names out?
-Peter.Dintelmann\100Dresdner-Bank.com	peter.dintelmann\100dresdner-bank.com 
+Peter.Dintelmann\100Dresdner-Bank.com    peter.dintelmann\100dresdner-bank.com 
 # NOTE: There is an intentional trailing space in the line above
 pfeifer\100wait.de                      pfeifer\100charly.informatik.uni-dortmund.de
-+										upf\100de.uu.net
-rabbit\100rabbit.us						rabbit+bugs\100rabbit.us
++                                        upf\100de.uu.net
+rabbit\100rabbit.us                        rabbit+bugs\100rabbit.us
 phil\100perkpartners.com                phil\100finchcomputer.com
 pimlott\100idiomtech.com                andrew\100pimlott.net
-+										pimlott\100abel.math.harvard.edu
-pixel\100mandriva.com						pixel\100mandrakesoft.com
++                                        pimlott\100abel.math.harvard.edu
+pixel\100mandriva.com                        pixel\100mandrakesoft.com
 pne\100cpan.org                         philip.newton\100gmx.net
 +                                       philip.newton\100datenrevision.de
 +                                       pnewton\100gmx.de
 pprymmer\100factset.com                 pvhp\100forte.com
 public\100khwilliamson.com              khw\100karl.(none)
-+										khw\100khw-desktop.(none)
++                                        khw\100khw-desktop.(none)
 
 radu\100netsoft.ro                      rgreab\100fx.ro
 raphael.manfredi\100pobox.com           raphael_manfredi\100grenoble.hp.com
-renee.baecker\100smart-websolutions.de		reneeb\100reneeb-desktop.(none)
-richard.foley\100ubsw.com               richard.foley\100t-online.de
+renee.baecker\100smart-websolutions.de        reneeb\100reneeb-desktop.(none)
+richard.foley\100rfi.net                richard.foley\100t-online.de
 +                                       richard.foley\100ubs.com
-+                                       richard.foley\100rfi.net
++                                       richard.foley\100ubsw.com
 rick\100consumercontact.com             rick\100bort.ca
 +                                       rick.delaney\100rogers.com
 +                                       rick\100bort.ca
-+										rick.delaney\100home.com
++                                        rick.delaney\100home.com
 rjbs\100cpan.org                        rjbs-perl-p5p\100lists.manxome.org
 +                    perl.p5p\100rjbs.manxome.org
 rjk\100linguist.dartmouth.edu           rjk\100linguist.thayer.dartmouth.edu
 +                                       rjk-perl-p5p\100tamias.net
 rjray\100redhat.com                        rjray\100uswest.com
 rmgiroux\100acm.org                     rmgiroux\100hotmail.com
-+										mgiroux\100bear.com
++                                        mgiroux\100bear.com
 rmbarker\100cpan.org                    rmb1\100cise.npl.co.uk
 +                                       robin.barker\100npl.co.uk
 +                                       rmb\100cise.npl.co.uk
 robertmay\100cpan.org                   rob\100themayfamily.me.uk
-roberto\100keltia.freenix.fr			roberto\100eurocontrol.fr
+roberto\100keltia.freenix.fr            roberto\100eurocontrol.fr
 robin\100cpan.org                       robin\100kitsite.com
 roderick\100argon.org                   roderick\100gate.net
-+										roderick\100ibcinc.com
++                                        roderick\100ibcinc.com
 rootbeer\100teleport.com                rootbeer\100redcat.com
-+										tomphoenix\100unknown
++                                        tomphoenix\100unknown
 schubiger\100cpan.org                   steven\100accognoscere.org
 +                                       sts\100accognoscere.org
 +                                       schubiger\100gmail.com
@@ -649,10 +653,10 @@ schwern\100pobox.com                    schwern\100gmail.com
 +                                       schwern\100athens.arena-i.com
 +                                       schwern\100blackrider.aocn.com
 +                                       schwern\100ool-18b93024.dyn.optonline.net
-scotth\100sgi.com						author scotth\100sgi.com 842220273 +0000
-+										schotth\100sgi.com
-schwab\100suse.de						schwab\100issan.informatik.uni-dortmund.de
-+										schwab\100ls5.informatik.uni-dortmund.de
+scotth\100sgi.com                        author scotth\100sgi.com 842220273 +0000
++                                        schotth\100sgi.com
+schwab\100suse.de                        schwab\100issan.informatik.uni-dortmund.de
++                                        schwab\100ls5.informatik.uni-dortmund.de
 sebastien\100aperghis.net               maddingue\100free.fr
 +                                       saper\100cpan.org
 shlomif\100vipe.technion.ac.il          shlomif\100iglu.org.il
@@ -664,8 +668,8 @@ simon\100simon-cozens.org               simon\100pembro4.pmb.ox.ac.uk
 slaven\100rezic.de                      slaven.rezic\100berlin.de
 +                                       srezic\100iconmobile.com
 +                                       srezic\100cpan.org
-+										eserte\100cs.tu-berlin.de
-+										eserte\100vran.herceg.de
++                                        eserte\100cs.tu-berlin.de
++                                        eserte\100vran.herceg.de
 smcc\100mit.edu                         smcc\100ocf.berkeley.edu
 +                                       smcc\100csua.berkeley.edu
 +                                       alias\100mcs.com
@@ -676,16 +680,16 @@ spider\100orb.nashua.nh.us              spider\100web.zk3.dec.com
 +                                       spider\100peano.zk3.dec.com
 +                                       spider.boardman\100orb.nashua.nh.us>
 +                                       spidb\100cpan.org
-+										spider.boardman\100orb.nashua.nh.us
-+										root\100peano.zk3.dec.com
++                                        spider.boardman\100orb.nashua.nh.us
++                                        root\100peano.zk3.dec.com
 spp\100ds.net                           spp\100psa.pencom.com
 +                                       spp\100psasolar.colltech.com
 +                                       spp\100spotter.yi.org
 stef\100mongueurs.net                   stef\100payrard.net
 +                                       s.payrard\100wanadoo.fr
-+										properler\100freesurf.fr
-+										stef\100francenet.fr
-sthoenna\100efn.org						ysth\100raven.shiftboard.com
++                                        properler\100freesurf.fr
++                                        stef\100francenet.fr
+sthoenna\100efn.org                        ysth\100raven.shiftboard.com
 
 tassilo.parseval\100post.rwth-aachen.de tassilo.von.parseval\100rwth-aachen.de
 tchrist\100perl.com                      tchrist\100mox.perl.com
@@ -693,8 +697,8 @@ tchrist\100perl.com                      tchrist\100mox.perl.com
 thomas.dorner\100start.de                tdorner\100amadeus.net
 tjenness\100cpan.org                     t.jenness\100jach.hawaii.edu
 +                                        timj\100jach.hawaii.edu
-tobez\100tobez.org						tobez\100plab.ku.dk
-tom\100compton.nu						thh\100cyberscience.com
+tobez\100tobez.org                       tobez\100plab.ku.dk
+tom\100compton.nu                        thh\100cyberscience.com
 tom.horsley\100mail.ccur.com             tom.horsley\100ccur.com
 +                                        tom\100amber.ssd.hcsc.com
 
@@ -708,4 +712,4 @@ whatever\100davidnicol.com                davidnicol\100gmail.com
 wolfgang.laun\100alcatel.at               wolfgang.laun\100chello.at
 +                                         wolfgang.laun\100thalesgroup.com
 +                                         wolfgang.laun\100gmail.com
-yath\100yath.de							  yath-perlbug\100yath.de
+yath\100yath.de                            yath-perlbug\100yath.de
