@@ -10,33 +10,63 @@
 
 struct gp {
     SV *	gp_sv;		/* scalar value */
-    U32		gp_refcnt;	/* how many globs point to this? */
     struct io *	gp_io;		/* filehandle value */
-    CV *	gp_form;	/* format value */
-    AV *	gp_av;		/* array value */
-    HV *	gp_hv;		/* hash value */
-    GV *	gp_egv;		/* effective gv, if *glob */
     CV *	gp_cv;		/* subroutine value */
     U32		gp_cvgen;	/* generational validity of cached gv_cv */
-    U32		gp_flags;	/* XXX unused */
+    U32		gp_refcnt;	/* how many globs point to this? */
+    HV *	gp_hv;		/* hash value */
+    AV *	gp_av;		/* array value */
+    CV *	gp_form;	/* format value */
+    GV *	gp_egv;		/* effective gv, if *glob */
     line_t	gp_line;	/* line first declared at (for -w) */
-    char *	gp_file;	/* file first declared in (for -w) */
+    HEK *	gp_file_hek;	/* file first declared in (for -w) */
 };
 
 #define GvXPVGV(gv)	((XPVGV*)SvANY(gv))
 
-#define GvGP(gv)	(GvXPVGV(gv)->xgv_gp)
-#define GvNAME(gv)	(GvXPVGV(gv)->xgv_name)
-#define GvNAMELEN(gv)	(GvXPVGV(gv)->xgv_namelen)
-#define GvSTASH(gv)	(GvXPVGV(gv)->xgv_stash)
-#define GvFLAGS(gv)	(GvXPVGV(gv)->xgv_flags)
 
-#define GvNAME_get(gv)		(0 + GvXPVGV(gv)->xgv_name)
-#define GvNAMELEN_get(gv)	(0 + GvXPVGV(gv)->xgv_namelen)
-#define	GvASSIGN_GENERATION(gv)		(0 + ((XPV*) SvANY(gv))->xpv_cur)
+#if defined (DEBUGGING) && defined(__GNUC__) && !defined(PERL_GCC_BRACE_GROUPS_FORBIDDEN) && !defined(__INTEL_COMPILER)
+#  define GvGP(gv)							\
+	(*({GV *const _gvgp = (GV *) (gv);				\
+	    assert(SvTYPE(_gvgp) == SVt_PVGV || SvTYPE(_gvgp) == SVt_PVLV); \
+	    assert(isGV_with_GP(_gvgp));				\
+	    &((_gvgp)->sv_u.svu_gp);}))
+#  define GvFLAGS(gv)							\
+	(*({GV *const _gvflags = (GV *) (gv);				\
+	    assert(SvTYPE(_gvflags) == SVt_PVGV || SvTYPE(_gvflags) == SVt_PVLV); \
+	    assert(isGV_with_GP(_gvflags));				\
+	    &(GvXPVGV(_gvflags)->xpv_cur);}))
+#  define GvSTASH(gv)							\
+	(*({ GV * const _gvstash = (GV *) (gv);				\
+	    assert(isGV_with_GP(_gvstash));				\
+	    assert(SvTYPE(_gvstash) == SVt_PVGV || SvTYPE(_gvstash) >= SVt_PVLV); \
+	    &(GvXPVGV(_gvstash)->xnv_u.xgv_stash);			\
+	 }))
+#  define GvNAME_HEK(gv)						\
+    (*({ GV * const _gvname_hek = (GV *) (gv);				\
+	   assert(isGV_with_GP(_gvname_hek));				\
+	   assert(SvTYPE(_gvname_hek) == SVt_PVGV || SvTYPE(_gvname_hek) >= SVt_PVLV); \
+	   assert(!SvVALID(_gvname_hek));				\
+	   &(GvXPVGV(_gvname_hek)->xiv_u.xivu_namehek);			\
+	 }))
+#  define GvNAME_get(gv)	({ assert(GvNAME_HEK(gv)); HEK_KEY(GvNAME_HEK(gv)); })
+#  define GvNAMELEN_get(gv)	({ assert(GvNAME_HEK(gv)); HEK_LEN(GvNAME_HEK(gv)); })
+#else
+#  define GvGP(gv)	((gv)->sv_u.svu_gp)
+#  define GvFLAGS(gv)	(GvXPVGV(gv)->xpv_cur)
+#  define GvSTASH(gv)	(GvXPVGV(gv)->xnv_u.xgv_stash)
+#  define GvNAME_HEK(gv)	(GvXPVGV(gv)->xiv_u.xivu_namehek)
+#  define GvNAME_get(gv)	HEK_KEY(GvNAME_HEK(gv))
+#  define GvNAMELEN_get(gv)	HEK_LEN(GvNAME_HEK(gv))
+#endif
+
+#define GvNAME(gv)	GvNAME_get(gv)
+#define GvNAMELEN(gv)	GvNAMELEN_get(gv)
+
+#define	GvASSIGN_GENERATION(gv)		(0 + ((XPV*) SvANY(gv))->xpv_len)
 #define	GvASSIGN_GENERATION_set(gv,val)			\
 	STMT_START { assert(SvTYPE(gv) == SVt_PVGV);	\
-		(((XPV*) SvANY(gv))->xpv_cur = (val)); } STMT_END
+		(((XPV*) SvANY(gv))->xpv_len = (val)); } STMT_END
 
 /*
 =head1 GV Functions
@@ -58,16 +88,13 @@ Return the SV from the GV.
 #endif
 
 #define GvREFCNT(gv)	(GvGP(gv)->gp_refcnt)
-#define GvIO(gv)	((gv) && SvTYPE((SV*)gv) == SVt_PVGV && GvGP(gv) ? GvIOp(gv) : NULL)
+#define GvIO(gv)	((gv) && SvTYPE((const SV*)gv) == SVt_PVGV && GvGP(gv) ? GvIOp(gv) : NULL)
 #define GvIOp(gv)	(GvGP(gv)->gp_io)
 #define GvIOn(gv)	(GvIO(gv) ? GvIOp(gv) : GvIOp(gv_IOadd(gv)))
 
 #define GvFORM(gv)	(GvGP(gv)->gp_form)
 #define GvAV(gv)	(GvGP(gv)->gp_av)
 
-/* This macro is deprecated.  Do not use! */
-#define GvREFCNT_inc(gv) ((GV*)SvREFCNT_inc(gv))	/* DO NOT USE */
-
 #define GvAVn(gv)	(GvGP(gv)->gp_av ? \
 			 GvGP(gv)->gp_av : \
 			 GvGP(gv_AVadd(gv))->gp_av)
@@ -79,12 +106,11 @@ Return the SV from the GV.
 
 #define GvCV(gv)	(GvGP(gv)->gp_cv)
 #define GvCVGEN(gv)	(GvGP(gv)->gp_cvgen)
-#define GvCVu(gv)	(GvGP(gv)->gp_cvgen ? Nullcv : GvGP(gv)->gp_cv)
-
-#define GvGPFLAGS(gv)	(GvGP(gv)->gp_flags)
+#define GvCVu(gv)	(GvGP(gv)->gp_cvgen ? NULL : GvGP(gv)->gp_cv)
 
 #define GvLINE(gv)	(GvGP(gv)->gp_line)
-#define GvFILE(gv)	(GvGP(gv)->gp_file)
+#define GvFILE_HEK(gv)	(GvGP(gv)->gp_file_hek)
+#define GvFILE(gv)	(GvFILE_HEK(gv) ? HEK_KEY(GvFILE_HEK(gv)) : NULL)
 #define GvFILEGV(gv)	(gv_fetchfile(GvFILE(gv)))
 
 #define GvEGV(gv)	(GvGP(gv)->gp_egv)
@@ -137,24 +163,14 @@ Return the SV from the GV.
 #define GvIN_PAD_on(gv)		(GvFLAGS(gv) |= GVf_IN_PAD)
 #define GvIN_PAD_off(gv)	(GvFLAGS(gv) &= ~GVf_IN_PAD)
 
-/* XXX: all GvFLAGS options are used, borrowing GvGPFLAGS for the moment */
-
-#define GVf_UNIQUE           0x0001
-#define GvUNIQUE(gv)         (GvGP(gv) && (GvGPFLAGS(gv) & GVf_UNIQUE))
-#define GvUNIQUE_on(gv)      (GvGPFLAGS(gv) |= GVf_UNIQUE)
-#define GvUNIQUE_off(gv)     (GvGPFLAGS(gv) &= ~GVf_UNIQUE)
-
-#ifdef USE_ITHREADS
-#define GV_UNIQUE_CHECK
-#else
-#undef  GV_UNIQUE_CHECK
+#ifndef PERL_CORE
+#  define Nullgv Null(GV*)
 #endif
 
-#define Nullgv Null(GV*)
-
 #define DM_UID   0x003
 #define DM_RUID   0x001
 #define DM_EUID   0x002
+#define DM_ARRAY 0x004
 #define DM_GID   0x030
 #define DM_RGID   0x010
 #define DM_EGID   0x020
@@ -177,6 +193,8 @@ Return the SV from the GV.
 #define GV_NOEXPAND	0x40	/* Don't expand SvOK() entries to PVGV */
 #define GV_NOTQUAL	0x80	/* A plain symbol name, not qualified with a
 				   package (so skip checks for :: and ')  */
+#define GV_AUTOLOAD	0x100	/* gv_fetchmethod_flags() should AUTOLOAD  */
+#define GV_CROAK	0x200	/* gv_fetchmethod_flags() should croak  */
 
 /*      SVf_UTF8 (more accurately the return value from SvUTF8) is also valid
 	as a flag to gv_fetch_pvn_flags, so ensure it lies outside this range.
@@ -188,3 +206,18 @@ Return the SV from the GV.
 #define gv_fullname3(sv,gv,prefix) gv_fullname4(sv,gv,prefix,TRUE)
 #define gv_efullname3(sv,gv,prefix) gv_efullname4(sv,gv,prefix,TRUE)
 #define gv_fetchmethod(stash, name) gv_fetchmethod_autoload(stash, name, TRUE)
+
+#define gv_AVadd(gv) gv_add_by_type((gv), SVt_PVAV)
+#define gv_HVadd(gv) gv_add_by_type((gv), SVt_PVHV)
+#define gv_IOadd(gv) gv_add_by_type((gv), SVt_PVIO)
+#define gv_SVadd(gv) gv_add_by_type((gv), SVt_NULL)
+
+/*
+ * Local variables:
+ * c-indentation-style: bsd
+ * c-basic-offset: 4
+ * indent-tabs-mode: t
+ * End:
+ *
+ * ex: set ts=8 sts=4 sw=4 noet:
+ */
