@@ -4,15 +4,22 @@ _o='.o'
 afs='false'
 afsroot='/afs'
 alignbytes='4'
-archlib='/usr/local/lib/perl5/5.9/unknown'
-archlibexp='/usr/local/lib/perl5/5.9/unknown'
+aphostname='/bin/hostname'
+archlib='/usr/local/lib/perl5/5.11/unknown'
+archlibexp='/usr/local/lib/perl5/5.11/unknown'
 archname='unknown'
 asctime_r_proto='0'
 bin='/usr/local/bin'
+binexp='/usr/local/bin'
 byteorder='1234'
 castflags='0'
-charsize='1'
+cf_by='root@localhost'
+cf_time='Thu Jan  1 00:00:00 GMT 1970'
 clocktype='clock_t'
+cpplast='-'
+cppminus='-'
+cpprun='cc -E'
+cppstdin='cc -E'
 cpp_stuff='42'
 crypt_r_proto='0'
 ctermid_r_proto='0'
@@ -37,16 +44,27 @@ d_accessx='undef'
 d_aintl='undef'
 d_alarm='undef'
 d_archlib='undef'
+d_asctime64='undef'
 d_asctime_r='undef'
 d_atolf='undef'
 d_atoll='undef'
-d_attribut='undef'
+d_attribute_deprecated='undef'
+d_attribute_format='undef'
+d_attribute_malloc='undef'
+d_attribute_nonnull='undef'
+d_attribute_noreturn='undef'
+d_attribute_pure='undef'
+d_attribute_unused='undef'
+d_attribute_warn_unused_result='undef'
 d_bcmp='undef'
 d_bcopy='undef'
-d_bsd='undef'
 d_bsdgetpgrp='undef'
 d_bsdsetpgrp='undef'
+d_bsd='undef'
+d_builtin_choose_expr='undef'
+d_builtin_expect='undef'
 d_bzero='undef'
+d_c99_variadic_macros='undef'
 d_casti32='undef'
 d_castneg='undef'
 d_charvspr='undef'
@@ -54,39 +72,45 @@ d_chown='undef'
 d_chroot='undef'
 d_chsize='undef'
 d_class='undef'
+d_clearenv='undef'
 d_closedir='define'
 d_cmsghdr_s='undef'
 d_const='undef'
 d_copysignl='undef'
-d_crypt='undef'
+d_cplusplus='undef'
 d_crypt_r='undef'
+d_crypt='undef'
 d_csh='undef'
 d_ctermid_r='undef'
+d_ctermid='undef'
+d_ctime64='undef'
 d_ctime_r='undef'
 d_cuserid='undef'
 d_dbl_dig='undef'
 d_dbminitproto='undef'
+d_difftime64='undef'
 d_difftime='undef'
+d_dir_dd_fd='undef'
 d_dirfd='undef'
 d_dirnamlen='undef'
 d_dlerror='undef'
 d_dlopen='undef'
 d_dlsymun='undef'
 d_dosuid='undef'
-d_drand48_r='undef'
 d_drand48proto='undef'
+d_drand48_r='undef'
 d_dup2='undef'
 d_eaccess='undef'
-d_endgrent='undef'
 d_endgrent_r='undef'
+d_endgrent='undef'
 d_endhent='undef'
 d_endhostent_r='undef'
 d_endnent='undef'
 d_endnetent_r='undef'
 d_endpent='undef'
 d_endprotoent_r='undef'
-d_endpwent='undef'
 d_endpwent_r='undef'
+d_endpwent='undef'
 d_endsent='undef'
 d_endservent_r='undef'
 d_eofnblk='undef'
@@ -95,23 +119,23 @@ d_faststdio='undef'
 d_fchdir='undef'
 d_fchmod='undef'
 d_fchown='undef'
-d_fcntl='undef'
 d_fcntl_can_lock='undef'
+d_fcntl='undef'
 d_fd_macros='undef'
-d_fd_set='undef'
 d_fds_bits='undef'
+d_fd_set='undef'
 d_fgetpos='undef'
-d_finite='undef'
 d_finitel='undef'
+d_finite='undef'
 d_flexfnam='undef'
-d_flock='undef'
 d_flockproto='undef'
+d_flock='undef'
 d_fork='define'
-d_fp_class='undef'
 d_fpathconf='undef'
-d_fpclass='undef'
 d_fpclassify='undef'
 d_fpclassl='undef'
+d_fp_class='undef'
+d_fpclass='undef'
 d_fpos64_t='undef'
 d_frexpl='undef'
 d_fs_data_s='undef'
@@ -122,11 +146,15 @@ d_fstatvfs='undef'
 d_fsync='undef'
 d_ftello='undef'
 d_ftime='undef'
+d_futimes='undef'
+d_gdbm_ndbm_h_uses_prototypes='undef'
+d_gdbmndbm_h_uses_prototypes='undef'
+d_getaddrinfo='undef'
 d_getcwd='undef'
 d_getespwnam='undef'
 d_getfsstat='undef'
-d_getgrent='undef'
 d_getgrent_r='undef'
+d_getgrent='undef'
 d_getgrgid_r='undef'
 d_getgrnam_r='undef'
 d_getgrps='undef'
@@ -139,10 +167,11 @@ d_gethostbyname_r='undef'
 d_gethostent_r='undef'
 d_gethostprotos='undef'
 d_getitimer='undef'
-d_getlogin='undef'
 d_getlogin_r='undef'
-d_getmnt='undef'
+d_getlogin='undef'
 d_getmntent='undef'
+d_getmnt='undef'
+d_getnameinfo='undef'
 d_getnbyaddr='undef'
 d_getnbyname='undef'
 d_getnent='undef'
@@ -164,8 +193,8 @@ d_getprotobynumber_r='undef'
 d_getprotoent_r='undef'
 d_getprotoprotos='undef'
 d_getprpwnam='undef'
-d_getpwent='undef'
 d_getpwent_r='undef'
+d_getpwent='undef'
 d_getpwnam_r='undef'
 d_getpwuid_r='undef'
 d_getsbyname='undef'
@@ -176,27 +205,34 @@ d_getservbyport_r='undef'
 d_getservent_r='undef'
 d_getservprotos='undef'
 d_getspent='undef'
-d_getspnam='undef'
 d_getspnam_r='undef'
+d_getspnam='undef'
 d_gettimeod='undef'
+d_gmtime64='undef'
 d_gmtime_r='undef'
 d_gnulibc='undef'
 d_grpasswd='undef'
 d_hasmntopt='undef'
 d_htonl='undef'
 d_ilogbl='undef'
+d_inc_version_list='undef'
 d_index='undef'
 d_inetaton='undef'
+d_inetntop='undef'
+d_inetpton='undef'
 d_int64_t='undef'
 d_isascii='undef'
 d_isfinite='undef'
 d_isinf='undef'
-d_isnan='undef'
 d_isnanl='undef'
+d_isnan='undef'
 d_killpg='undef'
 d_lchown='undef'
 d_ldbl_dig='undef'
+d_libm_lib_version='undef'
 d_link='undef'
+d_localtime64='undef'
+d_localtime_r_needs_tzset='undef'
 d_localtime_r='undef'
 d_locconv='undef'
 d_lockf='undef'
@@ -205,48 +241,54 @@ d_longlong='undef'
 d_lseekproto='undef'
 d_lstat='undef'
 d_madvise='undef'
+d_malloc_good_size='undef'
+d_malloc_size='undef'
 d_mblen='undef'
 d_mbstowcs='undef'
 d_mbtowc='undef'
-d_memchr='undef'
-d_memcmp='undef'
-d_memcpy='undef'
+d_memchr='define'
+d_memcmp='define'
+d_memcpy='define'
 d_memmove='undef'
 d_memset='undef'
 d_mkdir='undef'
 d_mkdtemp='undef'
 d_mkfifo='undef'
-d_mkstemp='undef'
 d_mkstemps='undef'
+d_mkstemp='undef'
+d_mktime64='undef'
 d_mktime='undef'
 d_mmap='undef'
-d_modfl='undef'
-d_modflproto='undef'
 d_modfl_pow32_bug='undef'
+d_modflproto='undef'
+d_modfl='undef'
 d_mprotect='undef'
-d_msg='undef'
+d_msgctl='undef'
 d_msg_ctrunc='undef'
 d_msg_dontroute='undef'
+d_msgget='undef'
+d_msghdr_s='undef'
 d_msg_oob='undef'
 d_msg_peek='undef'
 d_msg_proxy='undef'
-d_msgctl='undef'
-d_msgget='undef'
-d_msghdr_s='undef'
 d_msgrcv='undef'
 d_msgsnd='undef'
+d_msg='undef'
 d_msync='undef'
 d_munmap='undef'
 d_mymalloc='undef'
+d_ndbm_h_uses_prototypes='undef'
 d_nice='undef'
 d_nl_langinfo='undef'
 d_nv_preserves_uv='undef'
-nv_preserves_uv_bits='0'
+d_nv_zero_is_allbits_zero='undef'
 d_off64_t='undef'
 d_old_pthread_create_joinable='undef'
 d_oldpthreads='undef'
 d_oldsock='undef'
 d_open3='undef'
+nv_overflows_integers_at='256.0*256.0*256.0*256.0*256.0*256.0*2.0*2.0*2.0*2.0*2.0'
+nv_preserves_uv_bits='0'
 d_pathconf='undef'
 d_pause='undef'
 d_perl_otherlibdirs='undef'
@@ -254,7 +296,9 @@ d_phostname='undef'
 d_pipe='undef'
 d_poll='undef'
 d_portable='undef'
+d_printf_format_null='undef'
 d_procselfexe='undef'
+d_pseudofork='undef'
 d_pthread_atfork='undef'
 d_pthread_attr_setscope='undef'
 d_pthread_yield='undef'
@@ -334,14 +378,18 @@ d_shmctl='undef'
 d_shmdt='undef'
 d_shmget='undef'
 d_sigaction='undef'
+d_signbit='undef'
 d_sigprocmask='undef'
 d_sigsetjmp='undef'
+d_sitearch='undef'
 d_sockatmark='undef'
+d_snprintf='undef'
 d_sockatmarkproto='undef'
 d_socket='undef'
 d_socklen_t='undef'
 d_sockpair='undef'
 d_socks5_init='undef'
+d_sprintf_returns_strlen='undef'
 d_sqrtl='undef'
 d_srand48_r='undef'
 d_srandom_r='undef'
@@ -365,6 +413,8 @@ d_strerrm='strerror(e)'
 d_strerror='undef'
 d_strerror_r='undef'
 d_strftime='undef'
+d_strlcat='undef'
+d_strlcpy='undef'
 d_strtod='undef'
 d_strtol='undef'
 d_strtold='undef'
@@ -387,6 +437,7 @@ d_tcsetpgrp='undef'
 d_telldir='undef'
 d_telldirproto='undef'
 d_time='define'
+d_timegm='undef'
 d_times='undef'
 d_tm_tm_gmtoff='undef'
 d_tm_tm_zone='undef'
@@ -400,6 +451,7 @@ d_umask='undef'
 d_uname='undef'
 d_union_semun='undef'
 d_unordered='undef'
+d_unsetenv='undef'
 d_usleep='undef'
 d_usleepproto='undef'
 d_ustat='undef'
@@ -412,6 +464,7 @@ d_voidsig='undef'
 d_voidtty=''
 d_volatile='undef'
 d_vprintf='define'
+d_vsnprintf='undef'
 d_wait4='undef'
 d_waitpid='undef'
 d_wcstombs='undef'
@@ -420,11 +473,15 @@ d_writev='undef'
 d_xenix='undef'
 db_hashtype='u_int32_t'
 db_prefixtype='size_t'
+db_version_major='0'
+db_version_minor='0'
+db_version_patch='0'
 defvoidused=1
 direntrytype='struct dirent'
 doublesize='8'
 drand01="((rand() & 0x7FFF) / (double) ((unsigned long)1 << 15))"
 drand48_r_proto='0'
+dtrace=''
 eagain='EAGAIN'
 ebcdic='undef'
 endgrent_r_proto='0'
@@ -438,7 +495,9 @@ fflushall='undef'
 firstmakefile='makefile'
 fpossize='4'
 fpostype=int
-freetype=int
+freetype=void
+full_csh=''
+full_sed=''
 getgrent_r_proto='0'
 getgrgid_r_proto='0'
 getgrnam_r_proto='0'
@@ -476,6 +535,7 @@ i64type='int64_t'
 i8size='1'
 i8type='char'
 i_arpainet='undef'
+i_assert='define'
 i_bsdioctl=''
 i_crypt='undef'
 i_db='undef'
@@ -488,6 +548,8 @@ i_float='undef'
 i_fp='undef'
 i_fp_class='undef'
 i_gdbm='undef'
+i_gdbm_ndbm='undef'
+i_gdbmndbm='undef'
 i_grp='undef'
 i_ieeefp='undef'
 i_inttypes='undef'
@@ -497,6 +559,7 @@ i_limits='undef'
 i_locale='undef'
 i_machcthr='undef'
 i_malloc='undef'
+i_mallocmalloc='undef'
 i_math='define'
 i_memory='undef'
 i_mntent='undef'
@@ -531,6 +594,7 @@ i_sysmode='undef'
 i_sysmount='undef'
 i_sysndir='undef'
 i_sysparam='undef'
+i_syspoll='undef'
 i_sysresrc='undef'
 i_syssecrt='undef'
 i_sysselct='undef'
@@ -572,8 +636,10 @@ longlongsize=8
 longsize='4'
 lseeksize=4
 lseektype=int
+mad='undef'
 malloctype='int*'
 malloctype='void *'
+mmaptype='void *'
 modetype='mode_t'
 modetype=int
 multiarch='undef'
@@ -592,13 +658,17 @@ nvsize='8'
 nvtype='double'
 o_nonblock='O_NONBLOCK'
 obj_ext='.o'
+old_pthread_create_joinable=''
 optimize='-O2'
 orderlib='false'
 osname='unknown'
+osvers='unknown'
+otherlibdirs=' '
+package='perl5'
 phostname='hostname'
 pidtype=int
-privlib='/usr/local/lib/perl5/5.9'
-privlibexp='/usr/local/lib/perl5/5.9'
+privlib='/usr/local/lib/perl5/5.11'
+privlibexp='/usr/local/lib/perl5/5.11'
 procselfexe=''
 prototype='undef'
 ptrsize='4'
@@ -611,18 +681,22 @@ randseedtype='int'
 rd_nodata='-1'
 readdir64_r_proto='0'
 readdir_r_proto='0'
-sPRIEUldbl='"llE"'
-sPRIFUldbl='"llF"'
-sPRIGUldbl='"llG"'
-sPRIXU64='"LX"'
+sGMTIME_max='2147483647'
+sGMTIME_min='0'
+sLOCALTIME_max='2147483647'
+sLOCALTIME_min='0'
 sPRId64='"Ld"'
 sPRIeldbl='"lle"'
+sPRIEUldbl='"llE"'
 sPRIfldbl='"llf"'
+sPRIFUldbl='"llF"'
 sPRIgldbl='"llg"'
+sPRIGUldbl='"llG"'
 sPRIi64='"Li"'
 sPRIo64='"Lo"'
 sPRIu64='"Lu"'
 sPRIx64='"Lx"'
+sPRIXU64='"LX"'
 sSCNfldbl='"llf"'
 sched_yield='sched_yield()'
 scriptdir='/usr/local/bin'
@@ -637,18 +711,26 @@ setnetent_r_proto='0'
 setprotoent_r_proto='0'
 setpwent_r_proto='0'
 setservent_r_proto='0'
+sh='/bin/sh'
 shmattype='void *'
-shortsize=2
+shortsize='2'
 sig_name_init='0'
 sig_num_init='0'
 sig_size='1'
 signal_t=int
+sitearch='/usr/local/lib/perl5/5.11/unknown'
+sitearchexp='/usr/local/lib/perl5/5.11/unknown'
+sitelib='/usr/local/lib/perl5/5.11'
+sitelib_stem='/usr/local/lib/perl5'
+sitelibexp='/usr/local/lib/perl5/5.11'
 sizesize=4
 sizetype='size_t'
 socksizetype='int'
 srand48_r_proto='0'
 srandom_r_proto='0'
+src='.'
 ssizetype=int
+startperl='#!perl'
 stdchar=char
 stdio_base='((fp)->_IO_read_base)'
 stdio_bufsiz='((fp)->_IO_read_end - (fp)->_IO_read_base)'
@@ -657,6 +739,7 @@ stdio_filbuf=''
 stdio_ptr='((fp)->_IO_read_ptr)'
 stdio_stream_array=''
 strerror_r_proto='0'
+targetarch=''
 timetype=time_t
 tmpnam_r_proto='0'
 touch='touch'
@@ -678,7 +761,9 @@ use5005threads='undef'
 use64bitall='undef'
 use64bitint='undef'
 usecrosscompile='undef'
+usedevel='undef'
 usedl='undef'
+usedtrace='undef'
 usefaststdio='undef'
 useithreads='undef'
 uselargefiles='undef'
@@ -692,8 +777,10 @@ useopcode='true'
 useperlio='undef'
 useposix='true'
 usereentrant='undef'
+userelocatableinc='undef'
 usesfio='false'
 useshrplib='false'
+usesitecustomize='undef'
 usesocks='undef'
 usethreads='undef'
 usevendorprefix='undef'
@@ -704,5 +791,9 @@ uvsize='4'
 uvtype='unsigned long'
 uvuformat='"lu"'
 uvxformat='"lx"'
+vendorarch=''
+vendorarchexp=''
+vendorlib_stem=''
+vendorlibexp=''
 versiononly='undef'
 voidflags=1
